"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.isPythOracle = exports.isSwitchboardOracle = exports.parseSwitchboardOracle = exports.parseSwitchboardOracleV2 = exports.parseSwitchboardOracleV1 = exports.StubOracle = void 0;
const client_1 = require("@pythnetwork/client");
const web3_js_1 = require("@solana/web3.js");
const sbv2_lite_1 = __importDefault(require("@switchboard-xyz/sbv2-lite"));
const I80F48_1 = require("../numbers/I80F48");
const SBV1_DEVNET_PID = new web3_js_1.PublicKey('7azgmy1pFXHikv36q1zZASvFq5vFa39TT9NweVugKKTU');
const SBV1_MAINNET_PID = new web3_js_1.PublicKey('DtmE9D2CSB4L5D6A15mraeEjrGMm6auWVzgaD8hK2tZM');
let sbv2DevnetProgram;
let sbv2MainnetProgram;
class StubOracle {
    publicKey;
    group;
    mint;
    price;
    lastUpdated;
    static from(publicKey, obj) {
        return new StubOracle(publicKey, obj.group, obj.mint, obj.price, obj.lastUpdated);
    }
    constructor(publicKey, group, mint, price, lastUpdated) {
        this.publicKey = publicKey;
        this.group = group;
        this.mint = mint;
        this.price = I80F48_1.I80F48.from(price);
        this.lastUpdated = lastUpdated;
    }
}
exports.StubOracle = StubOracle;
// https://gist.github.com/microwavedcola1/b741a11e6ee273a859f3ef00b35ac1f0
function parseSwitchboardOracleV1(accountInfo) {
    const price = accountInfo.data.readDoubleLE(1 + 32 + 4 + 4);
    const lastUpdatedSlot = parseInt(accountInfo.data.readBigUInt64LE(1 + 32 + 4 + 4 + 8).toString());
    return { price, lastUpdatedSlot };
}
exports.parseSwitchboardOracleV1 = parseSwitchboardOracleV1;
function parseSwitchboardOracleV2(program, accountInfo) {
    const price = program.decodeLatestAggregatorValue(accountInfo).toNumber();
    const lastUpdatedSlot = program
        .decodeAggregator(accountInfo)
        .latestConfirmedRound.roundOpenSlot.toNumber();
    if (!price || !lastUpdatedSlot)
        throw new Error('Unable to parse Switchboard Oracle V2');
    return { price, lastUpdatedSlot };
}
exports.parseSwitchboardOracleV2 = parseSwitchboardOracleV2;
/**
 *
 * @param accountInfo
 * @returns ui price
 */
async function parseSwitchboardOracle(accountInfo, connection) {
    if (accountInfo.owner.equals(sbv2_lite_1.default.devnetPid)) {
        if (!sbv2DevnetProgram) {
            sbv2DevnetProgram = await sbv2_lite_1.default.loadDevnet(connection);
        }
        return parseSwitchboardOracleV2(sbv2DevnetProgram, accountInfo);
    }
    if (accountInfo.owner.equals(sbv2_lite_1.default.mainnetPid)) {
        if (!sbv2MainnetProgram) {
            sbv2MainnetProgram = await sbv2_lite_1.default.loadMainnet(connection);
        }
        return parseSwitchboardOracleV2(sbv2MainnetProgram, accountInfo);
    }
    if (accountInfo.owner.equals(SBV1_DEVNET_PID) ||
        accountInfo.owner.equals(SBV1_MAINNET_PID)) {
        return parseSwitchboardOracleV1(accountInfo);
    }
    throw new Error(`Should not be reached!`);
}
exports.parseSwitchboardOracle = parseSwitchboardOracle;
function isSwitchboardOracle(accountInfo) {
    if (accountInfo.owner.equals(SBV1_DEVNET_PID) ||
        accountInfo.owner.equals(SBV1_MAINNET_PID) ||
        accountInfo.owner.equals(sbv2_lite_1.default.devnetPid) ||
        accountInfo.owner.equals(sbv2_lite_1.default.mainnetPid)) {
        return true;
    }
    return false;
}
exports.isSwitchboardOracle = isSwitchboardOracle;
function isPythOracle(accountInfo) {
    return accountInfo.data.readUInt32LE(0) === client_1.Magic;
}
exports.isPythOracle = isPythOracle;
